==> lsr-0.3.0.tar.gz: lsr-0.3.0/src/Task/TimerTask.py <==
'''
Defines a L{Task} to execute when a timed interval passes.

@author: Peter Parente
@organization: IBM Corporation
@copyright: Copyright (c) 2006 IBM Corporation
@license: Common Public License 1.0

All rights reserved. This program and the accompanying materials are made 
available under the terms of the Common Public License v1.0 which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/cpl1.0.php}
'''
import Base, Constants

class TimerTask(Base.Task):
  '''
  Executes when a timed interval passes. The interval should not be changed
  once this L{Task} has been registered. Only the interval set at registration
  time will be honored.

  This class registers its name and whether it should be monitored by default
  in an L{AEMonitor} using the L{Constants.registerTaskType}
  function when this module is first imported. The L{AEMonitor}
  can use this information to build its menus.  
  
  @ivar interval: Interval for the timer in seconds
  @type interval: integer
  '''
  Constants.registerTaskType('TimerTask', False)
  
  def __init__(self, interval, ident=None):
    '''
    Stores the desired interval.
    
    @param interval: Interval for the timer in seconds
    @type interval: integer
    @param ident: Programmatic identifier
    @type ident: string
    '''
    Base.Task.__init__(self, ident)
    self.interval = interval
  
  def getTimerInterval(self):
    '''
    @return: Interval for this timer
    @rtype: integer
    '''
    return self.interval
  
  def execute(self, interval, layer, **kwargs):
    '''
    Executes this L{Task} in response to a timer event. Called by
    L{Tier.Tier._executeTask}.
    
    @param interval: Interval in seconds on which the timer fires
    @type interval: integer
    @param layer: Layer on which the event occurred, one of 
      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
    @type layer: integer
    '''
    pass

==> lsr_0.4.0.orig.tar.gz: lsr-0.4.0/src/Task/TimerTask.py <==
'''
Defines a L{Task} to execute when a timed interval passes.

@author: Peter Parente
@organization: IBM Corporation
@copyright: Copyright (c) 2005, 2007 IBM Corporation
@license: The BSD License

All rights reserved. This program and the accompanying materials are made 
available under the terms of the BSD license which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/bsd-license.php}
'''
import Base

class TimerTask(Base.Task):
  '''
  Executes when a timed interval passes. The interval should not be changed
  once this L{Task} has been registered. Only the interval set at registration
  time will be honored.

  This class registers its name and whether it should be monitored by default
  in an L{AEMonitor} using the L{Base.registerTaskType}
  function when this module is first imported. The L{AEMonitor}
  can use this information to build its menus.  
  
  @ivar interval: Interval for the timer in seconds
  @type interval: integer
  '''
  Base.registerTaskType('TimerTask', False)
  
  def __init__(self, interval, ident=None):
    '''
    Stores the desired interval.
    
    @note: Changed from second to millisecond resolution
    
    @param interval: Interval for the timer in milliseconds
    @type interval: integer
    @param ident: Programmatic identifier
    @type ident: string
    '''
    Base.Task.__init__(self, ident)
    self.interval = interval
  
  def getTimerInterval(self):
    '''
    @return: Interval for this timer
    @rtype: integer
    '''
    return self.interval
  
  def execute(self, interval, layer, **kwargs):
    '''
    Executes this L{Task} in response to a timer event. Called by
    L{Tier.Tier._executeTask}.
    
    @param interval: Interval in seconds on which the timer fires
    @type interval: integer
    @param layer: Layer on which the event occurred
    @type layer: integer
    '''
    pass
